@@ -1,4 +1,4 @@
-from camera_simulator_alg.base_processor import BaseProcessor
+from .base_processor import BaseProcessor
 import numpy as np
 from functools import wraps 
 
