@@ -18,6 +18,7 @@ class Sensor(BaseProcessor):
 
         super().__init__(enable)
         self._gain = gain
+        self.value = 1
 
     @Lens(enable = True, height = HEIGHT_SIZE, width = WIDTH_SIZE).decorator
     def process(self, image: np.array) -> np.array:
@@ -60,3 +61,12 @@ class Sensor(BaseProcessor):
 
         self._gain = val
 
+    def __iter__(self):
+        return self
+
+    def __next__(self):
+        if self.value >= 10:
+            raise StopIteration
+        current = self.value
+        self.value += 1
+        return current
