@@ -1,6 +1,6 @@
 
-from camera_simulator_alg.sensor import Sensor
-import camera_simulator_alg.contants as ct
+from .sensor import Sensor
+from .contants import HEIGHT_SIZE, WIDTH_SIZE, GAIN
 import numpy as np
 
 def mymean():
@@ -9,10 +9,10 @@ def mymean():
     
     """
     # Generate random image.
-    random_image = np.random.rand(ct.HEIGHT_SIZE, ct.WIDTH_SIZE) * 255
+    random_image = np.random.rand(HEIGHT_SIZE, WIDTH_SIZE) * 255
 
     # Pass the image through a Sensor object
-    sensor = Sensor(enable = True, gain = ct.GAIN)
+    sensor = Sensor(enable = True, gain = GAIN)
     image = sensor.process(random_image)
 
     # Return the mean of the image.
